@@ -9,7 +9,6 @@ from typing import Any, Dict, Type, Optional, List, Union, Callable
 
 from dataclass_csv import DataclassWriter
 
-from kih_api.communication import telegram
 from kih_api.logger import logger
 
 
@@ -39,7 +38,7 @@ def get_environment() -> Environment:
     return Environment.PROD if get_environment_variable("ENV") == Environment.PROD else Environment.DEV
 
 def get_environment_variable(key: str) -> str:
-    value: str = get_environment_variable(key)
+    value: str = os.getenv(key)
     if value is not None:
         return value
     else:
@@ -130,6 +129,7 @@ def update_code_base(project_directory: str, main_branch_name: str = "main") ->
 def job(job_name: str) -> Callable:
     def decorator(func: Callable) -> Callable:
         def wrapper(*args: Any, **kwargs: Any) -> None:
+            from kih_api.communication import telegram
             try:
                 telegram.send_message(
                     telegram.constants.telegram_channel_development_username,
