@@ -1,9 +1,11 @@
 import os
 from typing import Dict
 
-API_KEY: str = os.getenv("TRANSFER_WISE_API_KEY")
+from kih_api import global_common
+
+API_KEY: str = global_common.get_environment_variable("TRANSFER_WISE_API_KEY")
 HEADERS: Dict[str, str] = {"Authorization": f"Bearer {API_KEY}"}
-ENDPOINT_BASE_SANDBOX: str = "https://api.sandbox.transferwise.tech/"
+ENDPOINT_BASE_SANDBOX: str = "https://api.sandbox.transferwise.tech/" if global_common.get_environment() == global_common.Environment.DEV else "https://api.transferwise.com/"
 ENDPOINT_BASE_LIVE: str = "https://api.transferwise.com/"
 ENDPOINT_BASE: str = ENDPOINT_BASE_SANDBOX
 ENDPOINT_PROFILES: str = ENDPOINT_BASE + "v1/profiles"
